@@ -1,8 +1,8 @@
 import re
 import abc
 import networkx as nx
-from src.query_graph.koutrika_query_graph import Query_graph, Relation, Attribute, Value, Function, FunctionType, OperatorType
-from src.template.kourtrika_template import Generic_template, Template
+from pylogos.query_graph.koutrika_query_graph import Query_graph, Relation, Attribute, Value, Function, FunctionType, OperatorType
+from pylogos.template.kourtrika_template import Generic_template, Template
 
 def compare_string_without_newline(str1, str2):
     str1 = re.sub(' +', ' ', str1)
